// pages/login/login.js
import WxValidate from '../../utils/wxValidate'
import { gender } from '../../utils/dict';
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '维护个人信息', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        form: { icon: [] },
        // 头像
        icon: [],
        // 性别
        genderList: gender
    },
    initValidate() {
        const rules = { nickname: { required: true }, phone: { required: true, tel: true }, }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { nickname: { required: '请输入昵称', }, phone: { required: '请输入账号', } };
        this.WxValidate = new WxValidate(rules, messages)
    },
    back: function () {
        wx.navigateBack({ url: '/pages/me/index' })
    },
    // 上傳圖片
    imgUpload: function (e) {
        const that = this;
        let data = that.data.icon;
        data.push(e.detail)
        that.setData({ icon: data })
    },
    // 删除图片
    imgDel: function (e) {
        const that = this;
        let list = that.data.icon;
        let arr = list.filter((i, index) => index != e.detail.index)
        that.setData({ icon: arr })
    },
    // 选择性别
    genderChange: function (e) {
        const that = this;
        let index = e.detail.value;
        let value = that.data.genderList[index];
        that.setData({ 'form.gender': value });
    },
    // 提交登录
    onSubmit: function (e) {
        const that = this;
        const params = e.detail.value;
        if (!this.WxValidate.checkForm(params)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            wx.getStorage({
                key: 'token',
                success: async res => {
                    const arr = await app.$post(`/courtAdmin/api/user/${res.data._id}`, { ...params, icon: that.data.icon });
                    if (arr.errcode == '0') {
                        wx.showToast({ title: `维护信息成功`, icon: 'success', duration: 2000 });
                        that.watchLogin();
                    } else wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
                },
                fail: res => {
                    wx.redirectTo({ url: '/pages/index/index', })
                }
            })
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        //验证规则函数
        this.initValidate();
        // 计算高度
        this.searchHeight();
        // 监听用户是否登录
        this.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                const arr = await app.$get(`/courtAdmin/api/user/${res.data._id}`);
                if (arr.errcode == '0') {
                    let form = arr.data;
                    that.setData({ form: form });
                    that.setData({ icon: form.icon });
                }
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})