// pages/login/login.js
import WxValidate from '../../utils/wxValidate';
const moment = require("../../utils/moment.min")
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '申请报名', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        // 用户信息
        user: {},
        // 比赛信息
        match_id: '629eb5f211f83364713232a1',
        matchInfo: {},
        // 团队信息
        teamInfo: {},
        // 弹框
        dialog: { title: '选择赛制', show: false, type: '1' },
        // 成员原列表
        userList: [],
        // 成员列表
        members: [],
        // 赛制信息
        formatList: [],
        format: [],
    },
    initValidate() {
        const rules = { match_name: { required: true } }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { match_name: { required: '请输入比赛名称' } };
        this.WxValidate = new WxValidate(rules, messages)
    },
    back: function () {
        wx.navigateBack({ url: '/pages/matchteam/index' })
    },
    // 选择成员
    changeMem: function () {
        const that = this;
        that.setData({ dialog: { title: '成员列表', show: true, type: '2' } })
    },
    // 选择成员
    onMemchange: function (e) {
        const that = this;
        let data = e.detail.value;
        let user = that.data.userList;
        let members = [];
        for (const val of data) {
            let arr = user.find((i) => i.user_id == val);
            if (arr) members.push(arr)
        }
        that.setData({ 'form.match_num': members.length })
        that.setData({ members: members })
    },
    // 删除成员
    memDel: function (e) {
        const that = this;
        const { user_id } = e.currentTarget.dataset;
        var members = that.data.members;
        for (var i = 0; i < members.length; i++) {
            if (members[i].user_id == user_id) members.splice(i, 1)
        }
        that.setData({ 'form.match_num': members.length })
        this.setData({ members: members })
    },
    // 选择赛制
    formatChange: function (e) {
        const that = this;
        const { value } = e.detail;
        let format = that.data.format;
        let data = that.data.formatList[value];
        let list = [];
        if (data) list = [...format, data]
        that.setData({ format: list })
    },
    // 删除赛制
    formatDel: function (e) {
        const that = this;
        let list = that.data.format;
        const { index } = e.currentTarget.dataset;
        list.splice(index, 1);
        that.setData({ format: list });
    },
    // 关闭弹框
    toClose: function () {
        const that = this;
        that.setData({ dialog: { title: '选择赛制', show: false } })
    },
    onSubmit: async function (e) {
        const that = this;
        const params = e.detail.value;
        const format = that.data.format;
        const members = that.data.members;
        const data = that.data.form;
        params.format = format;
        params.members = members;
        params.apply_time = moment().format('YYYY-MM-DD HH:mm:ss');
        params.logo = data.logo;
        if (!this.WxValidate.checkForm(params)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            if (params.format.length > 0 && params.members.length > 0) {
                const arr = await app.$post(`/courtAdmin/api/matchteam`, params);
                if (arr.errcode == 0) { wx.showToast({ title: `报名成功`, icon: 'success', duration: 2000 }); that.back(); }
                else wx.showToast({ title: arr.errmsg, icon: 'none', duration: 2000 })
            } else {
                wx.showToast({ title: `缺少必要信息`, icon: 'error', duration: 2000 })
            }
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        if (options && options.id) that.setData({ match_id: options.id })
        //验证规则函数
        this.initValidate();
        // 计算高度
        this.searchHeight();
        // 监听用户是否登录
        this.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        let match_id = that.data.match_id;
        wx.getStorage({
            key: 'token',
            success: async res => {
                that.setData({ user: res.data })
                // 查询比赛信息
                let arr = await app.$get(`/courtAdmin/api/match/${match_id}`);
                if (arr.errcode == '0') that.setData({ matchInfo: arr.data });
                that.setData({ formatList: arr.data.format })
                // 查询团队信息
                let aee = await app.$get(`/courtAdmin/api/team`, { create_id: res.data._id })
                if (aee.errcode == '0') that.setData({ teamInfo: aee.data[0] });
                // 表单赋值
                let att = {
                    // 比赛信息
                    match_id: arr.data._id,
                    match_name: arr.data.name,
                    // 参赛团队信息
                    team_id: aee.data[0]._id,
                    team_name: aee.data[0].name,
                    logo: aee.data[0].logo,
                    create_id: aee.data[0].create_id,
                    create_user: aee.data[0].create_user,
                    create_time: aee.data[0].create_time,
                }
                that.setData({ userList: aee.data[0].members });
                that.setData({ form: att })
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})